NAME

CXC::Gnuplot::V1::Key::Title

VERSION

version v0.29.3

OBJECT ATTRIBUTES

on

text

enhanced

justify

font

textcolor

CONSTRUCTORS

new

$object = $class->new( @args )

Construct an object from the supplied arguments.

Arguments may be supplied as a name/value list or as a single plain hash reference. As shorthand, a single scalar is used as the text parameter:

$object = $class->new( $text )

METHODS

to_hash

Returns a hashref whose contents can be passed to the constructor to generate a duplicate of the object.

opts

INTERNALS

SUPPORT

Bugs

Please report any bugs or feature requests to bug-cxc-gnuplot@rt.cpan.org or through the web interface at: https://rt.cpan.org/Public/Dist/Display.html?Name=CXC-Gnuplot

Source is available at

https://codeberg.org/CXC-Optics/p5-CXC-Gnuplot

and may be cloned from

https://codeberg.org/CXC-Optics/p5-CXC-Gnuplot.git

SEE ALSO

Please see those modules/websites for more information related to this module.

AUTHOR

Diab Jerius <djerius@cfa.harvard.edu>

COPYRIGHT AND LICENSE

This software is Copyright (c) 2024 by Smithsonian Astrophysical Observatory.

This is free software, licensed under:

The GNU General Public License, Version 3, June 2007